function best_score = checkFilteredSignal( r_original, r_filtered )
% compare filtered signal with the original (downsampled with M=5)
% IMPORTANT: filtered signal must be of same length (7201 samples)

r_filtered = r_filtered(:); % vectorize
r_original = r_original(:);

% check if length is fitting
if(length(r_original)~=length(r_filtered))
  error('Error: given signals do not match in length!');
end

% 'Pearson correlation coefficient' as a comparison score ( equivalent to
% 'angle' between signals)
comp_score = xcorr(r_filtered,r_original);

% take maximum (neglect time-shifts introduced by longer filters)
best_score = max(abs(comp_score))/(norm(r_filtered)*norm(r_original));

% Announce fitness
fprintf('Your signal fits the original with %3.3f%% !!!\n',best_score*100);




